"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var convert_bash_1 = require("./convert-bash");
describe('convert-bash', function () {
    describe('convertBashToWin', function () {
        test('should do simple complete conversion', function () {
            expect(convert_bash_1.convertBashToWin('#!/bin/bash\n' +
                '\n' +
                'SOME_VAR="/c/cygwin/path"\n' +
                'rm -rf $SOME_VAR')).toEqual('@echo off\n' +
                '\n' +
                'SET SOME_VAR=c:\\cygwin\\path\n' +
                'DEL /S %SOME_VAR%');
        });
        test('should transform single command', function () {
            expect(convert_bash_1.convertBashToWin('rm -rf /c/cygwin/path'))
                .toEqual('@echo off\n\nDEL /S c:\\cygwin\\path');
        });
        test('should handle "&&"', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi 1" && echo "there 2"'))
                .toEqual('@echo off\n\necho "hi 1" && echo "there 2"');
        });
        test('should handle "||"', function () {
            expect(convert_bash_1.convertBashToWin('echo "hi 1" || echo "there 2"'))
                .toEqual('@echo off\n\necho "hi 1" || echo "there 2"');
        });
        test('should handle simple if', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" == "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                '  echo "second line"\n' +
                'fi'))
                .toEqual('@echo off\n\nIF "%my_var%" == "" (\n  echo "my_var is empty"\n  echo "second line"\n)');
        });
        test('should handle if-else', function () {
            expect(convert_bash_1.convertBashToWin('if [ "$my_var" == "" ]; then\n' +
                '  echo "my_var is empty"\n' +
                'else\n' +
                '  echo "my_var is not empty"\n' +
                'fi'))
                .toEqual('@echo off\n\nIF "%my_var%" == "" (\n  echo "my_var is empty"\n) ELSE (\n  echo "my_var is not empty"\n)');
        });
        test('should transform complete example', function () {
            expect(convert_bash_1.convertBashToWin("#!/bin/bash\n\nSOME_VAR=\"/c/cygwin/path\"\nrm -rf $SOME_VAR\ncp /c/some/file /to/another/file\n\nmy_function () {\n  echo \"hello from my_function: $1\"\n}\n# call the function:\nmy_function\n# call the function with param:\nmy_function \"some param\"\n")).toEqual("@echo off\n\nSET SOME_VAR=c:\\cygwin\\path\nDEL /S %SOME_VAR%\nCOPY  c:\\some\\file \\to\\another\\file\nCALL :my_function\nCALL :my_function \"some param\"\n\nEXIT /B %ERRORLEVEL%\n\n:my_function\necho \"hello from my_function: %~1\"\nEXIT /B 0\n");
        });
    });
});
